@@ -38,6 +38,13 @@ if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
   
 
 #--------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020000" ):
+    from nonNewtonianIcoFlux.r2_0_0 import *
+    pass
+  
+
+#--------------------------------------------------------------------------------------
+
 def entry_point():
     try:
        import sys; argv = sys.argv
